import json

from new_experiment.pipeline.pipeline_process_spacy_dep_tag_wer import run_spacy_dep_tag_wer_pipeline
from new_experiment.pipeline.pipeline_process_spacy_ner_wer import run_spacy_ner_wer_pipeline
from new_experiment.pipeline.pipeline_process_spacy_pos_wer import run_spacy_pos_wer_pipeline
from new_experiment.pipeline.pipeline_process_word_classic_wer import run_word_wer_classic_pipeline
from new_experiment.pipeline.pipeline_process_word_embedding_wer import run_word_wer_embedding_pipeline
from new_experiment.queue_base import process_queue


def process_message(body: bytes):
    print(body)
    message_dict = json.loads(body.decode('utf-8'))
    print(message_dict)

    task = message_dict['task']
    dataset = message_dict['dataset']
    asr_name = message_dict['asr_name']
    if task == 'run_word_wer_classic_pipeline':
        run_word_wer_classic_pipeline(dataset, asr_name)
    elif task == 'run_word_wer_embedding_pipeline':
        run_word_wer_embedding_pipeline(dataset, asr_name)
    elif task == 'run_spacy_dep_tag_wer_pipeline':
        run_spacy_dep_tag_wer_pipeline(dataset, asr_name)
    elif task == 'run_spacy_ner_wer_pipeline':
        run_spacy_ner_wer_pipeline(dataset, asr_name)
    elif task == 'run_spacy_pos_wer_pipeline':
        run_spacy_pos_wer_pipeline(dataset, asr_name)
    else:
        raise Exception(f"Bad message {message_dict}")


if __name__ == '__main__':
    process_queue('asr_benchmark_experiments', process_message)
